@@ -15,7 +15,10 @@ Including another URLconf
 """
 from django.contrib import admin
 from django.urls import path
+from django.conf import settings
+
+ADMIN_SITE_URL = getattr(settings, "ADMIN_SITE_URL", "admin/")
 
 urlpatterns = [
-    path('admin/', admin.site.urls),
+    path(ADMIN_SITE_URL, admin.site.urls),
 ]
